summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLuke Chen <luke.chen@mongodb.com>2020-06-29 16:43:52 +1000
committerLuke Chen <luke.chen@mongodb.com>2020-06-29 16:43:52 +1000
commit90e259accd8444ed30f934f46ed016a710b41afc (patch)
tree4260e5be37accb65c33fce36c8a2b20bf877fab7
parentfeb50487c23cf6e61843ac6a0ed9ce0a92cd6f71 (diff)
downloadmongo-90e259accd8444ed30f934f46ed016a710b41afc.tar.gz
Import wiredtiger: 48cbc0a231da8005719ff1a1628aa14372e6f327 from branch mongodb-4.4
ref: f7cef255d7..48cbc0a231 for: 4.4.0-rc12 WT-6442 Add a statistic to track when we wipe durable timestamps in our out-of-order handling
-rw-r--r--src/third_party/wiredtiger/dist/stat_data.py3
-rw-r--r--src/third_party/wiredtiger/import.data2
-rw-r--r--src/third_party/wiredtiger/src/history/hs.c47
-rw-r--r--src/third_party/wiredtiger/src/include/stat.h3
-rw-r--r--src/third_party/wiredtiger/src/include/wiredtiger.in729
-rw-r--r--src/third_party/wiredtiger/src/support/stat.c10
6 files changed, 427 insertions, 367 deletions
diff --git a/src/third_party/wiredtiger/dist/stat_data.py b/src/third_party/wiredtiger/dist/stat_data.py
index afabc69b5ae..494e862c987 100644
--- a/src/third_party/wiredtiger/dist/stat_data.py
+++ b/src/third_party/wiredtiger/dist/stat_data.py
@@ -304,6 +304,9 @@ connection_stats = [
CacheStat('cache_hs_key_truncate_mix_ts_restart', 'history store key truncation calls that returned restart'),
CacheStat('cache_hs_ondisk', 'history store table on-disk size', 'no_clear,no_scale,size'),
CacheStat('cache_hs_ondisk_max', 'history store table max on-disk size', 'no_clear,no_scale,size'),
+ CacheStat('cache_hs_order_fixup_insert', 'history store table out-of-order updates that were fixed up during insertion'),
+ CacheStat('cache_hs_order_fixup_move', 'history store table out-of-order updates that were fixed up by moving existing records'),
+ CacheStat('cache_hs_order_lose_durable_timestamp', 'history store table out-of-order resolved updates that lose their durable timestamp'),
CacheStat('cache_hs_read', 'history store table reads'),
CacheStat('cache_hs_read_miss', 'history store table reads missed'),
CacheStat('cache_hs_read_squash', 'history store table reads requiring squashed modifies'),
diff --git a/src/third_party/wiredtiger/import.data b/src/third_party/wiredtiger/import.data
index 36f5d187221..67ebc04ac39 100644
--- a/src/third_party/wiredtiger/import.data
+++ b/src/third_party/wiredtiger/import.data
@@ -2,5 +2,5 @@
"vendor": "wiredtiger",
"github": "wiredtiger/wiredtiger.git",
"branch": "mongodb-4.4",
- "commit": "f7cef255d7e0c555db21c149e8bfbad2cc4a60a7"
+ "commit": "48cbc0a231da8005719ff1a1628aa14372e6f327"
}
diff --git a/src/third_party/wiredtiger/src/include/stat.h b/src/third_party/wiredtiger/src/include/stat.h
index da31153d7c2..ca249170b10 100644
--- a/src/third_party/wiredtiger/src/include/stat.h
+++ b/src/third_party/wiredtiger/src/include/stat.h
@@ -405,6 +405,9 @@ struct __wt_connection_stats {
int64_t cache_hs_insert_restart;
int64_t cache_hs_ondisk_max;
int64_t cache_hs_ondisk;
+ int64_t cache_hs_order_lose_durable_timestamp;
+ int64_t cache_hs_order_fixup_move;
+ int64_t cache_hs_order_fixup_insert;
int64_t cache_hs_read;
int64_t cache_hs_read_miss;
int64_t cache_hs_read_squash;
diff --git a/src/third_party/wiredtiger/src/include/wiredtiger.in b/src/third_party/wiredtiger/src/include/wiredtiger.in
index d5a60e4c2ff..72d223e66b5 100644
--- a/src/third_party/wiredtiger/src/include/wiredtiger.in
+++ b/src/third_party/wiredtiger/src/include/wiredtiger.in
@@ -5209,828 +5209,843 @@ extern int wiredtiger_extension_terminate(WT_CONNECTION *connection);
#define WT_STAT_CONN_CACHE_HS_ONDISK_MAX 1108
/*! cache: history store table on-disk size */
#define WT_STAT_CONN_CACHE_HS_ONDISK 1109
+/*!
+ * cache: history store table out-of-order resolved updates that lose
+ * their durable timestamp
+ */
+#define WT_STAT_CONN_CACHE_HS_ORDER_LOSE_DURABLE_TIMESTAMP 1110
+/*!
+ * cache: history store table out-of-order updates that were fixed up by
+ * moving existing records
+ */
+#define WT_STAT_CONN_CACHE_HS_ORDER_FIXUP_MOVE 1111
+/*!
+ * cache: history store table out-of-order updates that were fixed up
+ * during insertion
+ */
+#define WT_STAT_CONN_CACHE_HS_ORDER_FIXUP_INSERT 1112
/*! cache: history store table reads */
-#define WT_STAT_CONN_CACHE_HS_READ 1110
+#define WT_STAT_CONN_CACHE_HS_READ 1113
/*! cache: history store table reads missed */
-#define WT_STAT_CONN_CACHE_HS_READ_MISS 1111
+#define WT_STAT_CONN_CACHE_HS_READ_MISS 1114
/*! cache: history store table reads requiring squashed modifies */
-#define WT_STAT_CONN_CACHE_HS_READ_SQUASH 1112
+#define WT_STAT_CONN_CACHE_HS_READ_SQUASH 1115
/*! cache: history store table remove calls due to key truncation */
-#define WT_STAT_CONN_CACHE_HS_REMOVE_KEY_TRUNCATE 1113
+#define WT_STAT_CONN_CACHE_HS_REMOVE_KEY_TRUNCATE 1116
/*! cache: history store table writes requiring squashed modifies */
-#define WT_STAT_CONN_CACHE_HS_WRITE_SQUASH 1114
+#define WT_STAT_CONN_CACHE_HS_WRITE_SQUASH 1117
/*! cache: in-memory page passed criteria to be split */
-#define WT_STAT_CONN_CACHE_INMEM_SPLITTABLE 1115
+#define WT_STAT_CONN_CACHE_INMEM_SPLITTABLE 1118
/*! cache: in-memory page splits */
-#define WT_STAT_CONN_CACHE_INMEM_SPLIT 1116
+#define WT_STAT_CONN_CACHE_INMEM_SPLIT 1119
/*! cache: internal pages evicted */
-#define WT_STAT_CONN_CACHE_EVICTION_INTERNAL 1117
+#define WT_STAT_CONN_CACHE_EVICTION_INTERNAL 1120
/*! cache: internal pages queued for eviction */
-#define WT_STAT_CONN_CACHE_EVICTION_INTERNAL_PAGES_QUEUED 1118
+#define WT_STAT_CONN_CACHE_EVICTION_INTERNAL_PAGES_QUEUED 1121
/*! cache: internal pages seen by eviction walk */
-#define WT_STAT_CONN_CACHE_EVICTION_INTERNAL_PAGES_SEEN 1119
+#define WT_STAT_CONN_CACHE_EVICTION_INTERNAL_PAGES_SEEN 1122
/*! cache: internal pages seen by eviction walk that are already queued */
-#define WT_STAT_CONN_CACHE_EVICTION_INTERNAL_PAGES_ALREADY_QUEUED 1120
+#define WT_STAT_CONN_CACHE_EVICTION_INTERNAL_PAGES_ALREADY_QUEUED 1123
/*! cache: internal pages split during eviction */
-#define WT_STAT_CONN_CACHE_EVICTION_SPLIT_INTERNAL 1121
+#define WT_STAT_CONN_CACHE_EVICTION_SPLIT_INTERNAL 1124
/*! cache: leaf pages split during eviction */
-#define WT_STAT_CONN_CACHE_EVICTION_SPLIT_LEAF 1122
+#define WT_STAT_CONN_CACHE_EVICTION_SPLIT_LEAF 1125
/*! cache: maximum bytes configured */
-#define WT_STAT_CONN_CACHE_BYTES_MAX 1123
+#define WT_STAT_CONN_CACHE_BYTES_MAX 1126
/*! cache: maximum page size at eviction */
-#define WT_STAT_CONN_CACHE_EVICTION_MAXIMUM_PAGE_SIZE 1124
+#define WT_STAT_CONN_CACHE_EVICTION_MAXIMUM_PAGE_SIZE 1127
/*! cache: modified pages evicted */
-#define WT_STAT_CONN_CACHE_EVICTION_DIRTY 1125
+#define WT_STAT_CONN_CACHE_EVICTION_DIRTY 1128
/*! cache: modified pages evicted by application threads */
-#define WT_STAT_CONN_CACHE_EVICTION_APP_DIRTY 1126
+#define WT_STAT_CONN_CACHE_EVICTION_APP_DIRTY 1129
/*! cache: operations timed out waiting for space in cache */
-#define WT_STAT_CONN_CACHE_TIMED_OUT_OPS 1127
+#define WT_STAT_CONN_CACHE_TIMED_OUT_OPS 1130
/*! cache: overflow pages read into cache */
-#define WT_STAT_CONN_CACHE_READ_OVERFLOW 1128
+#define WT_STAT_CONN_CACHE_READ_OVERFLOW 1131
/*! cache: page split during eviction deepened the tree */
-#define WT_STAT_CONN_CACHE_EVICTION_DEEPEN 1129
+#define WT_STAT_CONN_CACHE_EVICTION_DEEPEN 1132
/*! cache: page written requiring history store records */
-#define WT_STAT_CONN_CACHE_WRITE_HS 1130
+#define WT_STAT_CONN_CACHE_WRITE_HS 1133
/*! cache: pages currently held in the cache */
-#define WT_STAT_CONN_CACHE_PAGES_INUSE 1131
+#define WT_STAT_CONN_CACHE_PAGES_INUSE 1134
/*! cache: pages evicted by application threads */
-#define WT_STAT_CONN_CACHE_EVICTION_APP 1132
+#define WT_STAT_CONN_CACHE_EVICTION_APP 1135
/*! cache: pages queued for eviction */
-#define WT_STAT_CONN_CACHE_EVICTION_PAGES_QUEUED 1133
+#define WT_STAT_CONN_CACHE_EVICTION_PAGES_QUEUED 1136
/*! cache: pages queued for eviction post lru sorting */
-#define WT_STAT_CONN_CACHE_EVICTION_PAGES_QUEUED_POST_LRU 1134
+#define WT_STAT_CONN_CACHE_EVICTION_PAGES_QUEUED_POST_LRU 1137
/*! cache: pages queued for urgent eviction */
-#define WT_STAT_CONN_CACHE_EVICTION_PAGES_QUEUED_URGENT 1135
+#define WT_STAT_CONN_CACHE_EVICTION_PAGES_QUEUED_URGENT 1138
/*! cache: pages queued for urgent eviction during walk */
-#define WT_STAT_CONN_CACHE_EVICTION_PAGES_QUEUED_OLDEST 1136
+#define WT_STAT_CONN_CACHE_EVICTION_PAGES_QUEUED_OLDEST 1139
/*! cache: pages read into cache */
-#define WT_STAT_CONN_CACHE_READ 1137
+#define WT_STAT_CONN_CACHE_READ 1140
/*! cache: pages read into cache after truncate */
-#define WT_STAT_CONN_CACHE_READ_DELETED 1138
+#define WT_STAT_CONN_CACHE_READ_DELETED 1141
/*! cache: pages read into cache after truncate in prepare state */
-#define WT_STAT_CONN_CACHE_READ_DELETED_PREPARED 1139
+#define WT_STAT_CONN_CACHE_READ_DELETED_PREPARED 1142
/*! cache: pages requested from the cache */
-#define WT_STAT_CONN_CACHE_PAGES_REQUESTED 1140
+#define WT_STAT_CONN_CACHE_PAGES_REQUESTED 1143
/*! cache: pages seen by eviction walk */
-#define WT_STAT_CONN_CACHE_EVICTION_PAGES_SEEN 1141
+#define WT_STAT_CONN_CACHE_EVICTION_PAGES_SEEN 1144
/*! cache: pages seen by eviction walk that are already queued */
-#define WT_STAT_CONN_CACHE_EVICTION_PAGES_ALREADY_QUEUED 1142
+#define WT_STAT_CONN_CACHE_EVICTION_PAGES_ALREADY_QUEUED 1145
/*! cache: pages selected for eviction unable to be evicted */
-#define WT_STAT_CONN_CACHE_EVICTION_FAIL 1143
+#define WT_STAT_CONN_CACHE_EVICTION_FAIL 1146
/*!
* cache: pages selected for eviction unable to be evicted as the parent
* page has overflow items
*/
-#define WT_STAT_CONN_CACHE_EVICTION_FAIL_PARENT_HAS_OVERFLOW_ITEMS 1144
+#define WT_STAT_CONN_CACHE_EVICTION_FAIL_PARENT_HAS_OVERFLOW_ITEMS 1147
/*!
* cache: pages selected for eviction unable to be evicted because of
* active children on an internal page
*/
-#define WT_STAT_CONN_CACHE_EVICTION_FAIL_ACTIVE_CHILDREN_ON_AN_INTERNAL_PAGE 1145
+#define WT_STAT_CONN_CACHE_EVICTION_FAIL_ACTIVE_CHILDREN_ON_AN_INTERNAL_PAGE 1148
/*!
* cache: pages selected for eviction unable to be evicted because of
* failure in reconciliation
*/
-#define WT_STAT_CONN_CACHE_EVICTION_FAIL_IN_RECONCILIATION 1146
+#define WT_STAT_CONN_CACHE_EVICTION_FAIL_IN_RECONCILIATION 1149
/*! cache: pages walked for eviction */
-#define WT_STAT_CONN_CACHE_EVICTION_WALK 1147
+#define WT_STAT_CONN_CACHE_EVICTION_WALK 1150
/*! cache: pages written from cache */
-#define WT_STAT_CONN_CACHE_WRITE 1148
+#define WT_STAT_CONN_CACHE_WRITE 1151
/*! cache: pages written requiring in-memory restoration */
-#define WT_STAT_CONN_CACHE_WRITE_RESTORE 1149
+#define WT_STAT_CONN_CACHE_WRITE_RESTORE 1152
/*! cache: percentage overhead */
-#define WT_STAT_CONN_CACHE_OVERHEAD 1150
+#define WT_STAT_CONN_CACHE_OVERHEAD 1153
/*! cache: tracked bytes belonging to internal pages in the cache */
-#define WT_STAT_CONN_CACHE_BYTES_INTERNAL 1151
+#define WT_STAT_CONN_CACHE_BYTES_INTERNAL 1154
/*! cache: tracked bytes belonging to leaf pages in the cache */
-#define WT_STAT_CONN_CACHE_BYTES_LEAF 1152
+#define WT_STAT_CONN_CACHE_BYTES_LEAF 1155
/*! cache: tracked dirty bytes in the cache */
-#define WT_STAT_CONN_CACHE_BYTES_DIRTY 1153
+#define WT_STAT_CONN_CACHE_BYTES_DIRTY 1156
/*! cache: tracked dirty pages in the cache */
-#define WT_STAT_CONN_CACHE_PAGES_DIRTY 1154
+#define WT_STAT_CONN_CACHE_PAGES_DIRTY 1157
/*! cache: unmodified pages evicted */
-#define WT_STAT_CONN_CACHE_EVICTION_CLEAN 1155
+#define WT_STAT_CONN_CACHE_EVICTION_CLEAN 1158
/*! capacity: background fsync file handles considered */
-#define WT_STAT_CONN_FSYNC_ALL_FH_TOTAL 1156
+#define WT_STAT_CONN_FSYNC_ALL_FH_TOTAL 1159
/*! capacity: background fsync file handles synced */
-#define WT_STAT_CONN_FSYNC_ALL_FH 1157
+#define WT_STAT_CONN_FSYNC_ALL_FH 1160
/*! capacity: background fsync time (msecs) */
-#define WT_STAT_CONN_FSYNC_ALL_TIME 1158
+#define WT_STAT_CONN_FSYNC_ALL_TIME 1161
/*! capacity: bytes read */
-#define WT_STAT_CONN_CAPACITY_BYTES_READ 1159
+#define WT_STAT_CONN_CAPACITY_BYTES_READ 1162
/*! capacity: bytes written for checkpoint */
-#define WT_STAT_CONN_CAPACITY_BYTES_CKPT 1160
+#define WT_STAT_CONN_CAPACITY_BYTES_CKPT 1163
/*! capacity: bytes written for eviction */
-#define WT_STAT_CONN_CAPACITY_BYTES_EVICT 1161
+#define WT_STAT_CONN_CAPACITY_BYTES_EVICT 1164
/*! capacity: bytes written for log */
-#define WT_STAT_CONN_CAPACITY_BYTES_LOG 1162
+#define WT_STAT_CONN_CAPACITY_BYTES_LOG 1165
/*! capacity: bytes written total */
-#define WT_STAT_CONN_CAPACITY_BYTES_WRITTEN 1163
+#define WT_STAT_CONN_CAPACITY_BYTES_WRITTEN 1166
/*! capacity: threshold to call fsync */
-#define WT_STAT_CONN_CAPACITY_THRESHOLD 1164
+#define WT_STAT_CONN_CAPACITY_THRESHOLD 1167
/*! capacity: time waiting due to total capacity (usecs) */
-#define WT_STAT_CONN_CAPACITY_TIME_TOTAL 1165
+#define WT_STAT_CONN_CAPACITY_TIME_TOTAL 1168
/*! capacity: time waiting during checkpoint (usecs) */
-#define WT_STAT_CONN_CAPACITY_TIME_CKPT 1166
+#define WT_STAT_CONN_CAPACITY_TIME_CKPT 1169
/*! capacity: time waiting during eviction (usecs) */
-#define WT_STAT_CONN_CAPACITY_TIME_EVICT 1167
+#define WT_STAT_CONN_CAPACITY_TIME_EVICT 1170
/*! capacity: time waiting during logging (usecs) */
-#define WT_STAT_CONN_CAPACITY_TIME_LOG 1168
+#define WT_STAT_CONN_CAPACITY_TIME_LOG 1171
/*! capacity: time waiting during read (usecs) */
-#define WT_STAT_CONN_CAPACITY_TIME_READ 1169
+#define WT_STAT_CONN_CAPACITY_TIME_READ 1172
/*! connection: auto adjusting condition resets */
-#define WT_STAT_CONN_COND_AUTO_WAIT_RESET 1170
+#define WT_STAT_CONN_COND_AUTO_WAIT_RESET 1173
/*! connection: auto adjusting condition wait calls */
-#define WT_STAT_CONN_COND_AUTO_WAIT 1171
+#define WT_STAT_CONN_COND_AUTO_WAIT 1174
/*!
* connection: auto adjusting condition wait raced to update timeout and
* skipped updating
*/
-#define WT_STAT_CONN_COND_AUTO_WAIT_SKIPPED 1172
+#define WT_STAT_CONN_COND_AUTO_WAIT_SKIPPED 1175
/*! connection: detected system time went backwards */
-#define WT_STAT_CONN_TIME_TRAVEL 1173
+#define WT_STAT_CONN_TIME_TRAVEL 1176
/*! connection: files currently open */
-#define WT_STAT_CONN_FILE_OPEN 1174
+#define WT_STAT_CONN_FILE_OPEN 1177
/*! connection: memory allocations */
-#define WT_STAT_CONN_MEMORY_ALLOCATION 1175
+#define WT_STAT_CONN_MEMORY_ALLOCATION 1178
/*! connection: memory frees */
-#define WT_STAT_CONN_MEMORY_FREE 1176
+#define WT_STAT_CONN_MEMORY_FREE 1179
/*! connection: memory re-allocations */
-#define WT_STAT_CONN_MEMORY_GROW 1177
+#define WT_STAT_CONN_MEMORY_GROW 1180
/*! connection: pthread mutex condition wait calls */
-#define WT_STAT_CONN_COND_WAIT 1178
+#define WT_STAT_CONN_COND_WAIT 1181
/*! connection: pthread mutex shared lock read-lock calls */
-#define WT_STAT_CONN_RWLOCK_READ 1179
+#define WT_STAT_CONN_RWLOCK_READ 1182
/*! connection: pthread mutex shared lock write-lock calls */
-#define WT_STAT_CONN_RWLOCK_WRITE 1180
+#define WT_STAT_CONN_RWLOCK_WRITE 1183
/*! connection: total fsync I/Os */
-#define WT_STAT_CONN_FSYNC_IO 1181
+#define WT_STAT_CONN_FSYNC_IO 1184
/*! connection: total read I/Os */
-#define WT_STAT_CONN_READ_IO 1182
+#define WT_STAT_CONN_READ_IO 1185
/*! connection: total write I/Os */
-#define WT_STAT_CONN_WRITE_IO 1183
+#define WT_STAT_CONN_WRITE_IO 1186
/*! cursor: Total number of entries skipped by cursor next calls */
-#define WT_STAT_CONN_CURSOR_NEXT_SKIP_TOTAL 1184
+#define WT_STAT_CONN_CURSOR_NEXT_SKIP_TOTAL 1187
/*! cursor: Total number of entries skipped by cursor prev calls */
-#define WT_STAT_CONN_CURSOR_PREV_SKIP_TOTAL 1185
+#define WT_STAT_CONN_CURSOR_PREV_SKIP_TOTAL 1188
/*!
* cursor: Total number of entries skipped to position the history store
* cursor
*/
-#define WT_STAT_CONN_CURSOR_SKIP_HS_CUR_POSITION 1186
+#define WT_STAT_CONN_CURSOR_SKIP_HS_CUR_POSITION 1189
/*! cursor: cached cursor count */
-#define WT_STAT_CONN_CURSOR_CACHED_COUNT 1187
+#define WT_STAT_CONN_CURSOR_CACHED_COUNT 1190
/*! cursor: cursor bulk loaded cursor insert calls */
-#define WT_STAT_CONN_CURSOR_INSERT_BULK 1188
+#define WT_STAT_CONN_CURSOR_INSERT_BULK 1191
/*! cursor: cursor close calls that result in cache */
-#define WT_STAT_CONN_CURSOR_CACHE 1189
+#define WT_STAT_CONN_CURSOR_CACHE 1192
/*! cursor: cursor create calls */
-#define WT_STAT_CONN_CURSOR_CREATE 1190
+#define WT_STAT_CONN_CURSOR_CREATE 1193
/*! cursor: cursor insert calls */
-#define WT_STAT_CONN_CURSOR_INSERT 1191
+#define WT_STAT_CONN_CURSOR_INSERT 1194
/*! cursor: cursor insert key and value bytes */
-#define WT_STAT_CONN_CURSOR_INSERT_BYTES 1192
+#define WT_STAT_CONN_CURSOR_INSERT_BYTES 1195
/*! cursor: cursor modify calls */
-#define WT_STAT_CONN_CURSOR_MODIFY 1193
+#define WT_STAT_CONN_CURSOR_MODIFY 1196
/*! cursor: cursor modify key and value bytes affected */
-#define WT_STAT_CONN_CURSOR_MODIFY_BYTES 1194
+#define WT_STAT_CONN_CURSOR_MODIFY_BYTES 1197
/*! cursor: cursor modify value bytes modified */
-#define WT_STAT_CONN_CURSOR_MODIFY_BYTES_TOUCH 1195
+#define WT_STAT_CONN_CURSOR_MODIFY_BYTES_TOUCH 1198
/*! cursor: cursor next calls */
-#define WT_STAT_CONN_CURSOR_NEXT 1196
+#define WT_STAT_CONN_CURSOR_NEXT 1199
/*!
* cursor: cursor next calls that skip greater than or equal to 100
* entries
*/
-#define WT_STAT_CONN_CURSOR_NEXT_SKIP_GE_100 1197
+#define WT_STAT_CONN_CURSOR_NEXT_SKIP_GE_100 1200
/*! cursor: cursor next calls that skip less than 100 entries */
-#define WT_STAT_CONN_CURSOR_NEXT_SKIP_LT_100 1198
+#define WT_STAT_CONN_CURSOR_NEXT_SKIP_LT_100 1201
/*! cursor: cursor operation restarted */
-#define WT_STAT_CONN_CURSOR_RESTART 1199
+#define WT_STAT_CONN_CURSOR_RESTART 1202
/*! cursor: cursor prev calls */
-#define WT_STAT_CONN_CURSOR_PREV 1200
+#define WT_STAT_CONN_CURSOR_PREV 1203
/*!
* cursor: cursor prev calls that skip greater than or equal to 100
* entries
*/
-#define WT_STAT_CONN_CURSOR_PREV_SKIP_GE_100 1201
+#define WT_STAT_CONN_CURSOR_PREV_SKIP_GE_100 1204
/*! cursor: cursor prev calls that skip less than 100 entries */
-#define WT_STAT_CONN_CURSOR_PREV_SKIP_LT_100 1202
+#define WT_STAT_CONN_CURSOR_PREV_SKIP_LT_100 1205
/*! cursor: cursor remove calls */
-#define WT_STAT_CONN_CURSOR_REMOVE 1203
+#define WT_STAT_CONN_CURSOR_REMOVE 1206
/*! cursor: cursor remove key bytes removed */
-#define WT_STAT_CONN_CURSOR_REMOVE_BYTES 1204
+#define WT_STAT_CONN_CURSOR_REMOVE_BYTES 1207
/*! cursor: cursor reserve calls */
-#define WT_STAT_CONN_CURSOR_RESERVE 1205
+#define WT_STAT_CONN_CURSOR_RESERVE 1208
/*! cursor: cursor reset calls */
-#define WT_STAT_CONN_CURSOR_RESET 1206
+#define WT_STAT_CONN_CURSOR_RESET 1209
/*! cursor: cursor search calls */
-#define WT_STAT_CONN_CURSOR_SEARCH 1207
+#define WT_STAT_CONN_CURSOR_SEARCH 1210
/*! cursor: cursor search history store calls */
-#define WT_STAT_CONN_CURSOR_SEARCH_HS 1208
+#define WT_STAT_CONN_CURSOR_SEARCH_HS 1211
/*! cursor: cursor search near calls */
-#define WT_STAT_CONN_CURSOR_SEARCH_NEAR 1209
+#define WT_STAT_CONN_CURSOR_SEARCH_NEAR 1212
/*! cursor: cursor sweep buckets */
-#define WT_STAT_CONN_CURSOR_SWEEP_BUCKETS 1210
+#define WT_STAT_CONN_CURSOR_SWEEP_BUCKETS 1213
/*! cursor: cursor sweep cursors closed */
-#define WT_STAT_CONN_CURSOR_SWEEP_CLOSED 1211
+#define WT_STAT_CONN_CURSOR_SWEEP_CLOSED 1214
/*! cursor: cursor sweep cursors examined */
-#define WT_STAT_CONN_CURSOR_SWEEP_EXAMINED 1212
+#define WT_STAT_CONN_CURSOR_SWEEP_EXAMINED 1215
/*! cursor: cursor sweeps */
-#define WT_STAT_CONN_CURSOR_SWEEP 1213
+#define WT_STAT_CONN_CURSOR_SWEEP 1216
/*! cursor: cursor truncate calls */
-#define WT_STAT_CONN_CURSOR_TRUNCATE 1214
+#define WT_STAT_CONN_CURSOR_TRUNCATE 1217
/*! cursor: cursor update calls */
-#define WT_STAT_CONN_CURSOR_UPDATE 1215
+#define WT_STAT_CONN_CURSOR_UPDATE 1218
/*! cursor: cursor update key and value bytes */
-#define WT_STAT_CONN_CURSOR_UPDATE_BYTES 1216
+#define WT_STAT_CONN_CURSOR_UPDATE_BYTES 1219
/*! cursor: cursor update value size change */
-#define WT_STAT_CONN_CURSOR_UPDATE_BYTES_CHANGED 1217
+#define WT_STAT_CONN_CURSOR_UPDATE_BYTES_CHANGED 1220
/*! cursor: cursors reused from cache */
-#define WT_STAT_CONN_CURSOR_REOPEN 1218
+#define WT_STAT_CONN_CURSOR_REOPEN 1221
/*! cursor: open cursor count */
-#define WT_STAT_CONN_CURSOR_OPEN_COUNT 1219
+#define WT_STAT_CONN_CURSOR_OPEN_COUNT 1222
/*! data-handle: connection data handle size */
-#define WT_STAT_CONN_DH_CONN_HANDLE_SIZE 1220
+#define WT_STAT_CONN_DH_CONN_HANDLE_SIZE 1223
/*! data-handle: connection data handles currently active */
-#define WT_STAT_CONN_DH_CONN_HANDLE_COUNT 1221
+#define WT_STAT_CONN_DH_CONN_HANDLE_COUNT 1224
/*! data-handle: connection sweep candidate became referenced */
-#define WT_STAT_CONN_DH_SWEEP_REF 1222
+#define WT_STAT_CONN_DH_SWEEP_REF 1225
/*! data-handle: connection sweep dhandles closed */
-#define WT_STAT_CONN_DH_SWEEP_CLOSE 1223
+#define WT_STAT_CONN_DH_SWEEP_CLOSE 1226
/*! data-handle: connection sweep dhandles removed from hash list */
-#define WT_STAT_CONN_DH_SWEEP_REMOVE 1224
+#define WT_STAT_CONN_DH_SWEEP_REMOVE 1227
/*! data-handle: connection sweep time-of-death sets */
-#define WT_STAT_CONN_DH_SWEEP_TOD 1225
+#define WT_STAT_CONN_DH_SWEEP_TOD 1228
/*! data-handle: connection sweeps */
-#define WT_STAT_CONN_DH_SWEEPS 1226
+#define WT_STAT_CONN_DH_SWEEPS 1229
/*! data-handle: session dhandles swept */
-#define WT_STAT_CONN_DH_SESSION_HANDLES 1227
+#define WT_STAT_CONN_DH_SESSION_HANDLES 1230
/*! data-handle: session sweep attempts */
-#define WT_STAT_CONN_DH_SESSION_SWEEPS 1228
+#define WT_STAT_CONN_DH_SESSION_SWEEPS 1231
/*! history: history pages added for eviction during garbage collection */
-#define WT_STAT_CONN_HS_GC_PAGES_EVICT 1229
+#define WT_STAT_CONN_HS_GC_PAGES_EVICT 1232
/*! history: history pages removed for garbage collection */
-#define WT_STAT_CONN_HS_GC_PAGES_REMOVED 1230
+#define WT_STAT_CONN_HS_GC_PAGES_REMOVED 1233
/*! history: history pages visited for garbage collection */
-#define WT_STAT_CONN_HS_GC_PAGES_VISITED 1231
+#define WT_STAT_CONN_HS_GC_PAGES_VISITED 1234
/*! lock: checkpoint lock acquisitions */
-#define WT_STAT_CONN_LOCK_CHECKPOINT_COUNT 1232
+#define WT_STAT_CONN_LOCK_CHECKPOINT_COUNT 1235
/*! lock: checkpoint lock application thread wait time (usecs) */
-#define WT_STAT_CONN_LOCK_CHECKPOINT_WAIT_APPLICATION 1233
+#define WT_STAT_CONN_LOCK_CHECKPOINT_WAIT_APPLICATION 1236
/*! lock: checkpoint lock internal thread wait time (usecs) */
-#define WT_STAT_CONN_LOCK_CHECKPOINT_WAIT_INTERNAL 1234
+#define WT_STAT_CONN_LOCK_CHECKPOINT_WAIT_INTERNAL 1237
/*! lock: dhandle lock application thread time waiting (usecs) */
-#define WT_STAT_CONN_LOCK_DHANDLE_WAIT_APPLICATION 1235
+#define WT_STAT_CONN_LOCK_DHANDLE_WAIT_APPLICATION 1238
/*! lock: dhandle lock internal thread time waiting (usecs) */
-#define WT_STAT_CONN_LOCK_DHANDLE_WAIT_INTERNAL 1236
+#define WT_STAT_CONN_LOCK_DHANDLE_WAIT_INTERNAL 1239
/*! lock: dhandle read lock acquisitions */
-#define WT_STAT_CONN_LOCK_DHANDLE_READ_COUNT 1237
+#define WT_STAT_CONN_LOCK_DHANDLE_READ_COUNT 1240
/*! lock: dhandle write lock acquisitions */
-#define WT_STAT_CONN_LOCK_DHANDLE_WRITE_COUNT 1238
+#define WT_STAT_CONN_LOCK_DHANDLE_WRITE_COUNT 1241
/*!
* lock: durable timestamp queue lock application thread time waiting
* (usecs)
*/
-#define WT_STAT_CONN_LOCK_DURABLE_TIMESTAMP_WAIT_APPLICATION 1239
+#define WT_STAT_CONN_LOCK_DURABLE_TIMESTAMP_WAIT_APPLICATION 1242
/*!
* lock: durable timestamp queue lock internal thread time waiting
* (usecs)
*/
-#define WT_STAT_CONN_LOCK_DURABLE_TIMESTAMP_WAIT_INTERNAL 1240
+#define WT_STAT_CONN_LOCK_DURABLE_TIMESTAMP_WAIT_INTERNAL 1243
/*! lock: durable timestamp queue read lock acquisitions */
-#define WT_STAT_CONN_LOCK_DURABLE_TIMESTAMP_READ_COUNT 1241
+#define WT_STAT_CONN_LOCK_DURABLE_TIMESTAMP_READ_COUNT 1244
/*! lock: durable timestamp queue write lock acquisitions */
-#define WT_STAT_CONN_LOCK_DURABLE_TIMESTAMP_WRITE_COUNT 1242
+#define WT_STAT_CONN_LOCK_DURABLE_TIMESTAMP_WRITE_COUNT 1245
/*! lock: metadata lock acquisitions */
-#define WT_STAT_CONN_LOCK_METADATA_COUNT 1243
+#define WT_STAT_CONN_LOCK_METADATA_COUNT 1246
/*! lock: metadata lock application thread wait time (usecs) */
-#define WT_STAT_CONN_LOCK_METADATA_WAIT_APPLICATION 1244
+#define WT_STAT_CONN_LOCK_METADATA_WAIT_APPLICATION 1247
/*! lock: metadata lock internal thread wait time (usecs) */
-#define WT_STAT_CONN_LOCK_METADATA_WAIT_INTERNAL 1245
+#define WT_STAT_CONN_LOCK_METADATA_WAIT_INTERNAL 1248
/*!
* lock: read timestamp queue lock application thread time waiting
* (usecs)
*/
-#define WT_STAT_CONN_LOCK_READ_TIMESTAMP_WAIT_APPLICATION 1246
+#define WT_STAT_CONN_LOCK_READ_TIMESTAMP_WAIT_APPLICATION 1249
/*! lock: read timestamp queue lock internal thread time waiting (usecs) */
-#define WT_STAT_CONN_LOCK_READ_TIMESTAMP_WAIT_INTERNAL 1247
+#define WT_STAT_CONN_LOCK_READ_TIMESTAMP_WAIT_INTERNAL 1250
/*! lock: read timestamp queue read lock acquisitions */
-#define WT_STAT_CONN_LOCK_READ_TIMESTAMP_READ_COUNT 1248
+#define WT_STAT_CONN_LOCK_READ_TIMESTAMP_READ_COUNT 1251
/*! lock: read timestamp queue write lock acquisitions */
-#define WT_STAT_CONN_LOCK_READ_TIMESTAMP_WRITE_COUNT 1249
+#define WT_STAT_CONN_LOCK_READ_TIMESTAMP_WRITE_COUNT 1252
/*! lock: schema lock acquisitions */
-#define WT_STAT_CONN_LOCK_SCHEMA_COUNT 1250
+#define WT_STAT_CONN_LOCK_SCHEMA_COUNT 1253
/*! lock: schema lock application thread wait time (usecs) */
-#define WT_STAT_CONN_LOCK_SCHEMA_WAIT_APPLICATION 1251
+#define WT_STAT_CONN_LOCK_SCHEMA_WAIT_APPLICATION 1254
/*! lock: schema lock internal thread wait time (usecs) */
-#define WT_STAT_CONN_LOCK_SCHEMA_WAIT_INTERNAL 1252
+#define WT_STAT_CONN_LOCK_SCHEMA_WAIT_INTERNAL 1255
/*!
* lock: table lock application thread time waiting for the table lock
* (usecs)
*/
-#define WT_STAT_CONN_LOCK_TABLE_WAIT_APPLICATION 1253
+#define WT_STAT_CONN_LOCK_TABLE_WAIT_APPLICATION 1256
/*!
* lock: table lock internal thread time waiting for the table lock
* (usecs)
*/
-#define WT_STAT_CONN_LOCK_TABLE_WAIT_INTERNAL 1254
+#define WT_STAT_CONN_LOCK_TABLE_WAIT_INTERNAL 1257
/*! lock: table read lock acquisitions */
-#define WT_STAT_CONN_LOCK_TABLE_READ_COUNT 1255
+#define WT_STAT_CONN_LOCK_TABLE_READ_COUNT 1258
/*! lock: table write lock acquisitions */
-#define WT_STAT_CONN_LOCK_TABLE_WRITE_COUNT 1256
+#define WT_STAT_CONN_LOCK_TABLE_WRITE_COUNT 1259
/*! lock: txn global lock application thread time waiting (usecs) */
-#define WT_STAT_CONN_LOCK_TXN_GLOBAL_WAIT_APPLICATION 1257
+#define WT_STAT_CONN_LOCK_TXN_GLOBAL_WAIT_APPLICATION 1260
/*! lock: txn global lock internal thread time waiting (usecs) */
-#define WT_STAT_CONN_LOCK_TXN_GLOBAL_WAIT_INTERNAL 1258
+#define WT_STAT_CONN_LOCK_TXN_GLOBAL_WAIT_INTERNAL 1261
/*! lock: txn global read lock acquisitions */
-#define WT_STAT_CONN_LOCK_TXN_GLOBAL_READ_COUNT 1259
+#define WT_STAT_CONN_LOCK_TXN_GLOBAL_READ_COUNT 1262
/*! lock: txn global write lock acquisitions */
-#define WT_STAT_CONN_LOCK_TXN_GLOBAL_WRITE_COUNT 1260
+#define WT_STAT_CONN_LOCK_TXN_GLOBAL_WRITE_COUNT 1263
/*! log: busy returns attempting to switch slots */
-#define WT_STAT_CONN_LOG_SLOT_SWITCH_BUSY 1261
+#define WT_STAT_CONN_LOG_SLOT_SWITCH_BUSY 1264
/*! log: force archive time sleeping (usecs) */
-#define WT_STAT_CONN_LOG_FORCE_ARCHIVE_SLEEP 1262
+#define WT_STAT_CONN_LOG_FORCE_ARCHIVE_SLEEP 1265
/*! log: log bytes of payload data */
-#define WT_STAT_CONN_LOG_BYTES_PAYLOAD 1263
+#define WT_STAT_CONN_LOG_BYTES_PAYLOAD 1266
/*! log: log bytes written */
-#define WT_STAT_CONN_LOG_BYTES_WRITTEN 1264
+#define WT_STAT_CONN_LOG_BYTES_WRITTEN 1267
/*! log: log files manually zero-filled */
-#define WT_STAT_CONN_LOG_ZERO_FILLS 1265
+#define WT_STAT_CONN_LOG_ZERO_FILLS 1268
/*! log: log flush operations */
-#define WT_STAT_CONN_LOG_FLUSH 1266
+#define WT_STAT_CONN_LOG_FLUSH 1269
/*! log: log force write operations */
-#define WT_STAT_CONN_LOG_FORCE_WRITE 1267
+#define WT_STAT_CONN_LOG_FORCE_WRITE 1270
/*! log: log force write operations skipped */
-#define WT_STAT_CONN_LOG_FORCE_WRITE_SKIP 1268
+#define WT_STAT_CONN_LOG_FORCE_WRITE_SKIP 1271
/*! log: log records compressed */
-#define WT_STAT_CONN_LOG_COMPRESS_WRITES 1269
+#define WT_STAT_CONN_LOG_COMPRESS_WRITES 1272
/*! log: log records not compressed */
-#define WT_STAT_CONN_LOG_COMPRESS_WRITE_FAILS 1270
+#define WT_STAT_CONN_LOG_COMPRESS_WRITE_FAILS 1273
/*! log: log records too small to compress */
-#define WT_STAT_CONN_LOG_COMPRESS_SMALL 1271
+#define WT_STAT_CONN_LOG_COMPRESS_SMALL 1274
/*! log: log release advances write LSN */
-#define WT_STAT_CONN_LOG_RELEASE_WRITE_LSN 1272
+#define WT_STAT_CONN_LOG_RELEASE_WRITE_LSN 1275
/*! log: log scan operations */
-#define WT_STAT_CONN_LOG_SCANS 1273
+#define WT_STAT_CONN_LOG_SCANS 1276
/*! log: log scan records requiring two reads */
-#define WT_STAT_CONN_LOG_SCAN_REREADS 1274
+#define WT_STAT_CONN_LOG_SCAN_REREADS 1277
/*! log: log server thread advances write LSN */
-#define WT_STAT_CONN_LOG_WRITE_LSN 1275
+#define WT_STAT_CONN_LOG_WRITE_LSN 1278
/*! log: log server thread write LSN walk skipped */
-#define WT_STAT_CONN_LOG_WRITE_LSN_SKIP 1276
+#define WT_STAT_CONN_LOG_WRITE_LSN_SKIP 1279
/*! log: log sync operations */
-#define WT_STAT_CONN_LOG_SYNC 1277
+#define WT_STAT_CONN_LOG_SYNC 1280
/*! log: log sync time duration (usecs) */
-#define WT_STAT_CONN_LOG_SYNC_DURATION 1278
+#define WT_STAT_CONN_LOG_SYNC_DURATION 1281
/*! log: log sync_dir operations */
-#define WT_STAT_CONN_LOG_SYNC_DIR 1279
+#define WT_STAT_CONN_LOG_SYNC_DIR 1282
/*! log: log sync_dir time duration (usecs) */
-#define WT_STAT_CONN_LOG_SYNC_DIR_DURATION 1280
+#define WT_STAT_CONN_LOG_SYNC_DIR_DURATION 1283
/*! log: log write operations */
-#define WT_STAT_CONN_LOG_WRITES 1281
+#define WT_STAT_CONN_LOG_WRITES 1284
/*! log: logging bytes consolidated */
-#define WT_STAT_CONN_LOG_SLOT_CONSOLIDATED 1282
+#define WT_STAT_CONN_LOG_SLOT_CONSOLIDATED 1285
/*! log: maximum log file size */
-#define WT_STAT_CONN_LOG_MAX_FILESIZE 1283
+#define WT_STAT_CONN_LOG_MAX_FILESIZE 1286
/*! log: number of pre-allocated log files to create */
-#define WT_STAT_CONN_LOG_PREALLOC_MAX 1284
+#define WT_STAT_CONN_LOG_PREALLOC_MAX 1287
/*! log: pre-allocated log files not ready and missed */
-#define WT_STAT_CONN_LOG_PREALLOC_MISSED 1285
+#define WT_STAT_CONN_LOG_PREALLOC_MISSED 1288
/*! log: pre-allocated log files prepared */
-#define WT_STAT_CONN_LOG_PREALLOC_FILES 1286
+#define WT_STAT_CONN_LOG_PREALLOC_FILES 1289
/*! log: pre-allocated log files used */
-#define WT_STAT_CONN_LOG_PREALLOC_USED 1287
+#define WT_STAT_CONN_LOG_PREALLOC_USED 1290
/*! log: records processed by log scan */
-#define WT_STAT_CONN_LOG_SCAN_RECORDS 1288
+#define WT_STAT_CONN_LOG_SCAN_RECORDS 1291
/*! log: slot close lost race */
-#define WT_STAT_CONN_LOG_SLOT_CLOSE_RACE 1289
+#define WT_STAT_CONN_LOG_SLOT_CLOSE_RACE 1292
/*! log: slot close unbuffered waits */
-#define WT_STAT_CONN_LOG_SLOT_CLOSE_UNBUF 1290
+#define WT_STAT_CONN_LOG_SLOT_CLOSE_UNBUF 1293
/*! log: slot closures */
-#define WT_STAT_CONN_LOG_SLOT_CLOSES 1291
+#define WT_STAT_CONN_LOG_SLOT_CLOSES 1294
/*! log: slot join atomic update races */
-#define WT_STAT_CONN_LOG_SLOT_RACES 1292
+#define WT_STAT_CONN_LOG_SLOT_RACES 1295
/*! log: slot join calls atomic updates raced */
-#define WT_STAT_CONN_LOG_SLOT_YIELD_RACE 1293
+#define WT_STAT_CONN_LOG_SLOT_YIELD_RACE 1296
/*! log: slot join calls did not yield */
-#define WT_STAT_CONN_LOG_SLOT_IMMEDIATE 1294
+#define WT_STAT_CONN_LOG_SLOT_IMMEDIATE 1297
/*! log: slot join calls found active slot closed */
-#define WT_STAT_CONN_LOG_SLOT_YIELD_CLOSE 1295
+#define WT_STAT_CONN_LOG_SLOT_YIELD_CLOSE 1298
/*! log: slot join calls slept */
-#define WT_STAT_CONN_LOG_SLOT_YIELD_SLEEP 1296
+#define WT_STAT_CONN_LOG_SLOT_YIELD_SLEEP 1299
/*! log: slot join calls yielded */
-#define WT_STAT_CONN_LOG_SLOT_YIELD 1297
+#define WT_STAT_CONN_LOG_SLOT_YIELD 1300
/*! log: slot join found active slot closed */
-#define WT_STAT_CONN_LOG_SLOT_ACTIVE_CLOSED 1298
+#define WT_STAT_CONN_LOG_SLOT_ACTIVE_CLOSED 1301
/*! log: slot joins yield time (usecs) */
-#define WT_STAT_CONN_LOG_SLOT_YIELD_DURATION 1299
+#define WT_STAT_CONN_LOG_SLOT_YIELD_DURATION 1302
/*! log: slot transitions unable to find free slot */
-#define WT_STAT_CONN_LOG_SLOT_NO_FREE_SLOTS 1300
+#define WT_STAT_CONN_LOG_SLOT_NO_FREE_SLOTS 1303
/*! log: slot unbuffered writes */
-#define WT_STAT_CONN_LOG_SLOT_UNBUFFERED 1301
+#define WT_STAT_CONN_LOG_SLOT_UNBUFFERED 1304
/*! log: total in-memory size of compressed records */
-#define WT_STAT_CONN_LOG_COMPRESS_MEM 1302
+#define WT_STAT_CONN_LOG_COMPRESS_MEM 1305
/*! log: total log buffer size */
-#define WT_STAT_CONN_LOG_BUFFER_SIZE 1303
+#define WT_STAT_CONN_LOG_BUFFER_SIZE 1306
/*! log: total size of compressed records */
-#define WT_STAT_CONN_LOG_COMPRESS_LEN 1304
+#define WT_STAT_CONN_LOG_COMPRESS_LEN 1307
/*! log: written slots coalesced */
-#define WT_STAT_CONN_LOG_SLOT_COALESCED 1305
+#define WT_STAT_CONN_LOG_SLOT_COALESCED 1308
/*! log: yields waiting for previous log file close */
-#define WT_STAT_CONN_LOG_CLOSE_YIELDS 1306
+#define WT_STAT_CONN_LOG_CLOSE_YIELDS 1309
/*! perf: file system read latency histogram (bucket 1) - 10-49ms */
-#define WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_LT50 1307
+#define WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_LT50 1310
/*! perf: file system read latency histogram (bucket 2) - 50-99ms */
-#define WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_LT100 1308
+#define WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_LT100 1311
/*! perf: file system read latency histogram (bucket 3) - 100-249ms */
-#define WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_LT250 1309
+#define WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_LT250 1312
/*! perf: file system read latency histogram (bucket 4) - 250-499ms */
-#define WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_LT500 1310
+#define WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_LT500 1313
/*! perf: file system read latency histogram (bucket 5) - 500-999ms */
-#define WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_LT1000 1311
+#define WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_LT1000 1314
/*! perf: file system read latency histogram (bucket 6) - 1000ms+ */
-#define WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_GT1000 1312
+#define WT_STAT_CONN_PERF_HIST_FSREAD_LATENCY_GT1000 1315
/*! perf: file system write latency histogram (bucket 1) - 10-49ms */
-#define WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_LT50 1313
+#define WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_LT50 1316
/*! perf: file system write latency histogram (bucket 2) - 50-99ms */
-#define WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_LT100 1314
+#define WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_LT100 1317
/*! perf: file system write latency histogram (bucket 3) - 100-249ms */
-#define WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_LT250 1315
+#define WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_LT250 1318
/*! perf: file system write latency histogram (bucket 4) - 250-499ms */
-#define WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_LT500 1316
+#define WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_LT500 1319
/*! perf: file system write latency histogram (bucket 5) - 500-999ms */
-#define WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_LT1000 1317
+#define WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_LT1000 1320
/*! perf: file system write latency histogram (bucket 6) - 1000ms+ */
-#define WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_GT1000 1318
+#define WT_STAT_CONN_PERF_HIST_FSWRITE_LATENCY_GT1000 1321
/*! perf: operation read latency histogram (bucket 1) - 100-249us */
-#define WT_STAT_CONN_PERF_HIST_OPREAD_LATENCY_LT250 1319
+#define WT_STAT_CONN_PERF_HIST_OPREAD_LATENCY_LT250 1322
/*! perf: operation read latency histogram (bucket 2) - 250-499us */
-#define WT_STAT_CONN_PERF_HIST_OPREAD_LATENCY_LT500 1320
+#define WT_STAT_CONN_PERF_HIST_OPREAD_LATENCY_LT500 1323
/*! perf: operation read latency histogram (bucket 3) - 500-999us */
-#define WT_STAT_CONN_PERF_HIST_OPREAD_LATENCY_LT1000 1321
+#define WT_STAT_CONN_PERF_HIST_OPREAD_LATENCY_LT1000 1324
/*! perf: operation read latency histogram (bucket 4) - 1000-9999us */
-#define WT_STAT_CONN_PERF_HIST_OPREAD_LATENCY_LT10000 1322
+#define WT_STAT_CONN_PERF_HIST_OPREAD_LATENCY_LT10000 1325
/*! perf: operation read latency histogram (bucket 5) - 10000us+ */
-#define WT_STAT_CONN_PERF_HIST_OPREAD_LATENCY_GT10000 1323
+#define WT_STAT_CONN_PERF_HIST_OPREAD_LATENCY_GT10000 1326
/*! perf: operation write latency histogram (bucket 1) - 100-249us */
-#define WT_STAT_CONN_PERF_HIST_OPWRITE_LATENCY_LT250 1324
+#define WT_STAT_CONN_PERF_HIST_OPWRITE_LATENCY_LT250 1327
/*! perf: operation write latency histogram (bucket 2) - 250-499us */
-#define WT_STAT_CONN_PERF_HIST_OPWRITE_LATENCY_LT500 1325
+#define WT_STAT_CONN_PERF_HIST_OPWRITE_LATENCY_LT500 1328
/*! perf: operation write latency histogram (bucket 3) - 500-999us */
-#define WT_STAT_CONN_PERF_HIST_OPWRITE_LATENCY_LT1000 1326
+#define WT_STAT_CONN_PERF_HIST_OPWRITE_LATENCY_LT1000 1329
/*! perf: operation write latency histogram (bucket 4) - 1000-9999us */
-#define WT_STAT_CONN_PERF_HIST_OPWRITE_LATENCY_LT10000 1327
+#define WT_STAT_CONN_PERF_HIST_OPWRITE_LATENCY_LT10000 1330
/*! perf: operation write latency histogram (bucket 5) - 10000us+ */
-#define WT_STAT_CONN_PERF_HIST_OPWRITE_LATENCY_GT10000 1328
+#define WT_STAT_CONN_PERF_HIST_OPWRITE_LATENCY_GT10000 1331
/*! reconciliation: approximate byte size of timestamps in pages written */
-#define WT_STAT_CONN_REC_TIME_WINDOW_BYTES_TS 1329
+#define WT_STAT_CONN_REC_TIME_WINDOW_BYTES_TS 1332
/*!
* reconciliation: approximate byte size of transaction IDs in pages
* written
*/
-#define WT_STAT_CONN_REC_TIME_WINDOW_BYTES_TXN 1330
+#define WT_STAT_CONN_REC_TIME_WINDOW_BYTES_TXN 1333
/*! reconciliation: fast-path pages deleted */
-#define WT_STAT_CONN_REC_PAGE_DELETE_FAST 1331
+#define WT_STAT_CONN_REC_PAGE_DELETE_FAST 1334
/*! reconciliation: maximum seconds spent in a reconciliation call */
-#define WT_STAT_CONN_REC_MAXIMUM_SECONDS 1332
+#define WT_STAT_CONN_REC_MAXIMUM_SECONDS 1335
/*! reconciliation: page reconciliation calls */
-#define WT_STAT_CONN_REC_PAGES 1333
+#define WT_STAT_CONN_REC_PAGES 1336
/*! reconciliation: page reconciliation calls for eviction */
-#define WT_STAT_CONN_REC_PAGES_EVICTION 1334
+#define WT_STAT_CONN_REC_PAGES_EVICTION 1337
/*!
* reconciliation: page reconciliation calls that resulted in values with
* prepared transaction metadata
*/
-#define WT_STAT_CONN_REC_PAGES_WITH_PREPARE 1335
+#define WT_STAT_CONN_REC_PAGES_WITH_PREPARE 1338
/*!
* reconciliation: page reconciliation calls that resulted in values with
* timestamps
*/
-#define WT_STAT_CONN_REC_PAGES_WITH_TS 1336
+#define WT_STAT_CONN_REC_PAGES_WITH_TS 1339
/*!
* reconciliation: page reconciliation calls that resulted in values with
* transaction ids
*/
-#define WT_STAT_CONN_REC_PAGES_WITH_TXN 1337
+#define WT_STAT_CONN_REC_PAGES_WITH_TXN 1340
/*! reconciliation: pages deleted */
-#define WT_STAT_CONN_REC_PAGE_DELETE 1338
+#define WT_STAT_CONN_REC_PAGE_DELETE 1341
/*!
* reconciliation: pages written including an aggregated newest start
* durable timestamp
*/
-#define WT_STAT_CONN_REC_TIME_AGGR_NEWEST_START_DURABLE_TS 1339
+#define WT_STAT_CONN_REC_TIME_AGGR_NEWEST_START_DURABLE_TS 1342
/*!
* reconciliation: pages written including an aggregated newest stop
* durable timestamp
*/
-#define WT_STAT_CONN_REC_TIME_AGGR_NEWEST_STOP_DURABLE_TS 1340
+#define WT_STAT_CONN_REC_TIME_AGGR_NEWEST_STOP_DURABLE_TS 1343
/*!
* reconciliation: pages written including an aggregated newest stop
* timestamp
*/
-#define WT_STAT_CONN_REC_TIME_AGGR_NEWEST_STOP_TS 1341
+#define WT_STAT_CONN_REC_TIME_AGGR_NEWEST_STOP_TS 1344
/*!
* reconciliation: pages written including an aggregated newest stop
* transaction ID
*/
-#define WT_STAT_CONN_REC_TIME_AGGR_NEWEST_STOP_TXN 1342
+#define WT_STAT_CONN_REC_TIME_AGGR_NEWEST_STOP_TXN 1345
/*!
* reconciliation: pages written including an aggregated oldest start
* timestamp
*/
-#define WT_STAT_CONN_REC_TIME_AGGR_OLDEST_START_TS 1343
+#define WT_STAT_CONN_REC_TIME_AGGR_OLDEST_START_TS 1346
/*!
* reconciliation: pages written including an aggregated oldest start
* transaction ID
*/
-#define WT_STAT_CONN_REC_TIME_AGGR_OLDEST_START_TXN 1344
+#define WT_STAT_CONN_REC_TIME_AGGR_OLDEST_START_TXN 1347
/*! reconciliation: pages written including an aggregated prepare */
-#define WT_STAT_CONN_REC_TIME_AGGR_PREPARED 1345
+#define WT_STAT_CONN_REC_TIME_AGGR_PREPARED 1348
/*! reconciliation: pages written including at least one prepare state */
-#define WT_STAT_CONN_REC_TIME_WINDOW_PAGES_PREPARED 1346
+#define WT_STAT_CONN_REC_TIME_WINDOW_PAGES_PREPARED 1349
/*!
* reconciliation: pages written including at least one start durable
* timestamp
*/
-#define WT_STAT_CONN_REC_TIME_WINDOW_PAGES_DURABLE_START_TS 1347
+#define WT_STAT_CONN_REC_TIME_WINDOW_PAGES_DURABLE_START_TS 1350
/*! reconciliation: pages written including at least one start timestamp */
-#define WT_STAT_CONN_REC_TIME_WINDOW_PAGES_START_TS 1348
+#define WT_STAT_CONN_REC_TIME_WINDOW_PAGES_START_TS 1351
/*!
* reconciliation: pages written including at least one start transaction
* ID
*/
-#define WT_STAT_CONN_REC_TIME_WINDOW_PAGES_START_TXN 1349
+#define WT_STAT_CONN_REC_TIME_WINDOW_PAGES_START_TXN 1352
/*!
* reconciliation: pages written including at least one stop durable
* timestamp
*/
-#define WT_STAT_CONN_REC_TIME_WINDOW_PAGES_DURABLE_STOP_TS 1350
+#define WT_STAT_CONN_REC_TIME_WINDOW_PAGES_DURABLE_STOP_TS 1353
/*! reconciliation: pages written including at least one stop timestamp */
-#define WT_STAT_CONN_REC_TIME_WINDOW_PAGES_STOP_TS 1351
+#define WT_STAT_CONN_REC_TIME_WINDOW_PAGES_STOP_TS 1354
/*!
* reconciliation: pages written including at least one stop transaction
* ID
*/
-#define WT_STAT_CONN_REC_TIME_WINDOW_PAGES_STOP_TXN 1352
+#define WT_STAT_CONN_REC_TIME_WINDOW_PAGES_STOP_TXN 1355
/*! reconciliation: records written including a prepare state */
-#define WT_STAT_CONN_REC_TIME_WINDOW_PREPARED 1353
+#define WT_STAT_CONN_REC_TIME_WINDOW_PREPARED 1356
/*! reconciliation: records written including a start durable timestamp */
-#define WT_STAT_CONN_REC_TIME_WINDOW_DURABLE_START_TS 1354
+#define WT_STAT_CONN_REC_TIME_WINDOW_DURABLE_START_TS 1357
/*! reconciliation: records written including a start timestamp */
-#define WT_STAT_CONN_REC_TIME_WINDOW_START_TS 1355
+#define WT_STAT_CONN_REC_TIME_WINDOW_START_TS 1358
/*! reconciliation: records written including a start transaction ID */
-#define WT_STAT_CONN_REC_TIME_WINDOW_START_TXN 1356
+#define WT_STAT_CONN_REC_TIME_WINDOW_START_TXN 1359
/*! reconciliation: records written including a stop durable timestamp */
-#define WT_STAT_CONN_REC_TIME_WINDOW_DURABLE_STOP_TS 1357
+#define WT_STAT_CONN_REC_TIME_WINDOW_DURABLE_STOP_TS 1360
/*! reconciliation: records written including a stop timestamp */
-#define WT_STAT_CONN_REC_TIME_WINDOW_STOP_TS 1358
+#define WT_STAT_CONN_REC_TIME_WINDOW_STOP_TS 1361
/*! reconciliation: records written including a stop transaction ID */
-#define WT_STAT_CONN_REC_TIME_WINDOW_STOP_TXN 1359
+#define WT_STAT_CONN_REC_TIME_WINDOW_STOP_TXN 1362
/*! reconciliation: split bytes currently awaiting free */
-#define WT_STAT_CONN_REC_SPLIT_STASHED_BYTES 1360
+#define WT_STAT_CONN_REC_SPLIT_STASHED_BYTES 1363
/*! reconciliation: split objects currently awaiting free */
-#define WT_STAT_CONN_REC_SPLIT_STASHED_OBJECTS 1361
+#define WT_STAT_CONN_REC_SPLIT_STASHED_OBJECTS 1364
/*! session: open session count */
-#define WT_STAT_CONN_SESSION_OPEN 1362
+#define WT_STAT_CONN_SESSION_OPEN 1365
/*! session: session query timestamp calls */
-#define WT_STAT_CONN_SESSION_QUERY_TS 1363
+#define WT_STAT_CONN_SESSION_QUERY_TS 1366
/*! session: table alter failed calls */
-#define WT_STAT_CONN_SESSION_TABLE_ALTER_FAIL 1364
+#define WT_STAT_CONN_SESSION_TABLE_ALTER_FAIL 1367
/*! session: table alter successful calls */
-#define WT_STAT_CONN_SESSION_TABLE_ALTER_SUCCESS 1365
+#define WT_STAT_CONN_SESSION_TABLE_ALTER_SUCCESS 1368
/*! session: table alter unchanged and skipped */
-#define WT_STAT_CONN_SESSION_TABLE_ALTER_SKIP 1366
+#define WT_STAT_CONN_SESSION_TABLE_ALTER_SKIP 1369
/*! session: table compact failed calls */
-#define WT_STAT_CONN_SESSION_TABLE_COMPACT_FAIL 1367
+#define WT_STAT_CONN_SESSION_TABLE_COMPACT_FAIL 1370
/*! session: table compact successful calls */
-#define WT_STAT_CONN_SESSION_TABLE_COMPACT_SUCCESS 1368
+#define WT_STAT_CONN_SESSION_TABLE_COMPACT_SUCCESS 1371
/*! session: table create failed calls */
-#define WT_STAT_CONN_SESSION_TABLE_CREATE_FAIL 1369
+#define WT_STAT_CONN_SESSION_TABLE_CREATE_FAIL 1372
/*! session: table create successful calls */
-#define WT_STAT_CONN_SESSION_TABLE_CREATE_SUCCESS 1370
+#define WT_STAT_CONN_SESSION_TABLE_CREATE_SUCCESS 1373
/*! session: table drop failed calls */
-#define WT_STAT_CONN_SESSION_TABLE_DROP_FAIL 1371
+#define WT_STAT_CONN_SESSION_TABLE_DROP_FAIL 1374
/*! session: table drop successful calls */
-#define WT_STAT_CONN_SESSION_TABLE_DROP_SUCCESS 1372
+#define WT_STAT_CONN_SESSION_TABLE_DROP_SUCCESS 1375
/*! session: table import failed calls */
-#define WT_STAT_CONN_SESSION_TABLE_IMPORT_FAIL 1373
+#define WT_STAT_CONN_SESSION_TABLE_IMPORT_FAIL 1376
/*! session: table import successful calls */
-#define WT_STAT_CONN_SESSION_TABLE_IMPORT_SUCCESS 1374
+#define WT_STAT_CONN_SESSION_TABLE_IMPORT_SUCCESS 1377
/*! session: table rebalance failed calls */
-#define WT_STAT_CONN_SESSION_TABLE_REBALANCE_FAIL 1375
+#define WT_STAT_CONN_SESSION_TABLE_REBALANCE_FAIL 1378
/*! session: table rebalance successful calls */
-#define WT_STAT_CONN_SESSION_TABLE_REBALANCE_SUCCESS 1376
+#define WT_STAT_CONN_SESSION_TABLE_REBALANCE_SUCCESS 1379
/*! session: table rename failed calls */
-#define WT_STAT_CONN_SESSION_TABLE_RENAME_FAIL 1377
+#define WT_STAT_CONN_SESSION_TABLE_RENAME_FAIL 1380
/*! session: table rename successful calls */
-#define WT_STAT_CONN_SESSION_TABLE_RENAME_SUCCESS 1378
+#define WT_STAT_CONN_SESSION_TABLE_RENAME_SUCCESS 1381
/*! session: table salvage failed calls */
-#define WT_STAT_CONN_SESSION_TABLE_SALVAGE_FAIL 1379
+#define WT_STAT_CONN_SESSION_TABLE_SALVAGE_FAIL 1382
/*! session: table salvage successful calls */
-#define WT_STAT_CONN_SESSION_TABLE_SALVAGE_SUCCESS 1380
+#define WT_STAT_CONN_SESSION_TABLE_SALVAGE_SUCCESS 1383
/*! session: table truncate failed calls */
-#define WT_STAT_CONN_SESSION_TABLE_TRUNCATE_FAIL 1381
+#define WT_STAT_CONN_SESSION_TABLE_TRUNCATE_FAIL 1384
/*! session: table truncate successful calls */
-#define WT_STAT_CONN_SESSION_TABLE_TRUNCATE_SUCCESS 1382
+#define WT_STAT_CONN_SESSION_TABLE_TRUNCATE_SUCCESS 1385
/*! session: table verify failed calls */
-#define WT_STAT_CONN_SESSION_TABLE_VERIFY_FAIL 1383
+#define WT_STAT_CONN_SESSION_TABLE_VERIFY_FAIL 1386
/*! session: table verify successful calls */
-#define WT_STAT_CONN_SESSION_TABLE_VERIFY_SUCCESS 1384
+#define WT_STAT_CONN_SESSION_TABLE_VERIFY_SUCCESS 1387
/*! thread-state: active filesystem fsync calls */
-#define WT_STAT_CONN_THREAD_FSYNC_ACTIVE 1385
+#define WT_STAT_CONN_THREAD_FSYNC_ACTIVE 1388
/*! thread-state: active filesystem read calls */
-#define WT_STAT_CONN_THREAD_READ_ACTIVE 1386
+#define WT_STAT_CONN_THREAD_READ_ACTIVE 1389
/*! thread-state: active filesystem write calls */
-#define WT_STAT_CONN_THREAD_WRITE_ACTIVE 1387
+#define WT_STAT_CONN_THREAD_WRITE_ACTIVE 1390
/*! thread-yield: application thread time evicting (usecs) */
-#define WT_STAT_CONN_APPLICATION_EVICT_TIME 1388
+#define WT_STAT_CONN_APPLICATION_EVICT_TIME 1391
/*! thread-yield: application thread time waiting for cache (usecs) */
-#define WT_STAT_CONN_APPLICATION_CACHE_TIME 1389
+#define WT_STAT_CONN_APPLICATION_CACHE_TIME 1392
/*!
* thread-yield: connection close blocked waiting for transaction state
* stabilization
*/
-#define WT_STAT_CONN_TXN_RELEASE_BLOCKED 1390
+#define WT_STAT_CONN_TXN_RELEASE_BLOCKED 1393
/*! thread-yield: connection close yielded for lsm manager shutdown */
-#define WT_STAT_CONN_CONN_CLOSE_BLOCKED_LSM 1391
+#define WT_STAT_CONN_CONN_CLOSE_BLOCKED_LSM 1394
/*! thread-yield: data handle lock yielded */
-#define WT_STAT_CONN_DHANDLE_LOCK_BLOCKED 1392
+#define WT_STAT_CONN_DHANDLE_LOCK_BLOCKED 1395
/*!
* thread-yield: get reference for page index and slot time sleeping
* (usecs)
*/
-#define WT_STAT_CONN_PAGE_INDEX_SLOT_REF_BLOCKED 1393
+#define WT_STAT_CONN_PAGE_INDEX_SLOT_REF_BLOCKED 1396
/*! thread-yield: log server sync yielded for log write */
-#define WT_STAT_CONN_LOG_SERVER_SYNC_BLOCKED 1394
+#define WT_STAT_CONN_LOG_SERVER_SYNC_BLOCKED 1397
/*! thread-yield: page access yielded due to prepare state change */
-#define WT_STAT_CONN_PREPARED_TRANSITION_BLOCKED_PAGE 1395
+#define WT_STAT_CONN_PREPARED_TRANSITION_BLOCKED_PAGE 1398
/*! thread-yield: page acquire busy blocked */
-#define WT_STAT_CONN_PAGE_BUSY_BLOCKED 1396
+#define WT_STAT_CONN_PAGE_BUSY_BLOCKED 1399
/*! thread-yield: page acquire eviction blocked */
-#define WT_STAT_CONN_PAGE_FORCIBLE_EVICT_BLOCKED 1397
+#define WT_STAT_CONN_PAGE_FORCIBLE_EVICT_BLOCKED 1400
/*! thread-yield: page acquire locked blocked */
-#define WT_STAT_CONN_PAGE_LOCKED_BLOCKED 1398
+#define WT_STAT_CONN_PAGE_LOCKED_BLOCKED 1401
/*! thread-yield: page acquire read blocked */
-#define WT_STAT_CONN_PAGE_READ_BLOCKED 1399
+#define WT_STAT_CONN_PAGE_READ_BLOCKED 1402
/*! thread-yield: page acquire time sleeping (usecs) */
-#define WT_STAT_CONN_PAGE_SLEEP 1400
+#define WT_STAT_CONN_PAGE_SLEEP 1403
/*!
* thread-yield: page delete rollback time sleeping for state change
* (usecs)
*/
-#define WT_STAT_CONN_PAGE_DEL_ROLLBACK_BLOCKED 1401
+#define WT_STAT_CONN_PAGE_DEL_ROLLBACK_BLOCKED 1404
/*! thread-yield: page reconciliation yielded due to child modification */
-#define WT_STAT_CONN_CHILD_MODIFY_BLOCKED_PAGE 1402
+#define WT_STAT_CONN_CHILD_MODIFY_BLOCKED_PAGE 1405
/*! transaction: Number of prepared updates */
-#define WT_STAT_CONN_TXN_PREPARED_UPDATES_COUNT 1403
+#define WT_STAT_CONN_TXN_PREPARED_UPDATES_COUNT 1406
/*! transaction: durable timestamp queue entries walked */
-#define WT_STAT_CONN_TXN_DURABLE_QUEUE_WALKED 1404
+#define WT_STAT_CONN_TXN_DURABLE_QUEUE_WALKED 1407
/*! transaction: durable timestamp queue insert to empty */
-#define WT_STAT_CONN_TXN_DURABLE_QUEUE_EMPTY 1405
+#define WT_STAT_CONN_TXN_DURABLE_QUEUE_EMPTY 1408
/*! transaction: durable timestamp queue inserts to head */
-#define WT_STAT_CONN_TXN_DURABLE_QUEUE_HEAD 1406
+#define WT_STAT_CONN_TXN_DURABLE_QUEUE_HEAD 1409
/*! transaction: durable timestamp queue inserts total */
-#define WT_STAT_CONN_TXN_DURABLE_QUEUE_INSERTS 1407
+#define WT_STAT_CONN_TXN_DURABLE_QUEUE_INSERTS 1410
/*! transaction: durable timestamp queue length */
-#define WT_STAT_CONN_TXN_DURABLE_QUEUE_LEN 1408
+#define WT_STAT_CONN_TXN_DURABLE_QUEUE_LEN 1411
/*! transaction: prepared transactions */
-#define WT_STAT_CONN_TXN_PREPARE 1409
+#define WT_STAT_CONN_TXN_PREPARE 1412
/*! transaction: prepared transactions committed */
-#define WT_STAT_CONN_TXN_PREPARE_COMMIT 1410
+#define WT_STAT_CONN_TXN_PREPARE_COMMIT 1413
/*! transaction: prepared transactions currently active */
-#define WT_STAT_CONN_TXN_PREPARE_ACTIVE 1411
+#define WT_STAT_CONN_TXN_PREPARE_ACTIVE 1414
/*! transaction: prepared transactions rolled back */
-#define WT_STAT_CONN_TXN_PREPARE_ROLLBACK 1412
+#define WT_STAT_CONN_TXN_PREPARE_ROLLBACK 1415
/*! transaction: query timestamp calls */
-#define WT_STAT_CONN_TXN_QUERY_TS 1413
+#define WT_STAT_CONN_TXN_QUERY_TS 1416
/*! transaction: read timestamp queue entries walked */
-#define WT_STAT_CONN_TXN_READ_QUEUE_WALKED 1414
+#define WT_STAT_CONN_TXN_READ_QUEUE_WALKED 1417
/*! transaction: read timestamp queue insert to empty */
-#define WT_STAT_CONN_TXN_READ_QUEUE_EMPTY 1415
+#define WT_STAT_CONN_TXN_READ_QUEUE_EMPTY 1418
/*! transaction: read timestamp queue inserts to head */
-#define WT_STAT_CONN_TXN_READ_QUEUE_HEAD 1416
+#define WT_STAT_CONN_TXN_READ_QUEUE_HEAD 1419
/*! transaction: read timestamp queue inserts total */
-#define WT_STAT_CONN_TXN_READ_QUEUE_INSERTS 1417
+#define WT_STAT_CONN_TXN_READ_QUEUE_INSERTS 1420
/*! transaction: read timestamp queue length */
-#define WT_STAT_CONN_TXN_READ_QUEUE_LEN 1418
+#define WT_STAT_CONN_TXN_READ_QUEUE_LEN 1421
/*! transaction: rollback to stable calls */
-#define WT_STAT_CONN_TXN_RTS 1419
+#define WT_STAT_CONN_TXN_RTS 1422
/*!
* transaction: rollback to stable hs records with stop timestamps older
* than newer records
*/
-#define WT_STAT_CONN_TXN_RTS_HS_STOP_OLDER_THAN_NEWER_START 1420
+#define WT_STAT_CONN_TXN_RTS_HS_STOP_OLDER_THAN_NEWER_START 1423
/*! transaction: rollback to stable keys removed */
-#define WT_STAT_CONN_TXN_RTS_KEYS_REMOVED 1421
+#define WT_STAT_CONN_TXN_RTS_KEYS_REMOVED 1424
/*! transaction: rollback to stable keys restored */
-#define WT_STAT_CONN_TXN_RTS_KEYS_RESTORED 1422
+#define WT_STAT_CONN_TXN_RTS_KEYS_RESTORED 1425
/*! transaction: rollback to stable pages visited */
-#define WT_STAT_CONN_TXN_RTS_PAGES_VISITED 1423
+#define WT_STAT_CONN_TXN_RTS_PAGES_VISITED 1426
/*! transaction: rollback to stable restored tombstones from history store */
-#define WT_STAT_CONN_TXN_RTS_HS_RESTORE_TOMBSTONES 1424
+#define WT_STAT_CONN_TXN_RTS_HS_RESTORE_TOMBSTONES 1427
/*! transaction: rollback to stable sweeping history store keys */
-#define WT_STAT_CONN_TXN_RTS_SWEEP_HS_KEYS 1425
+#define WT_STAT_CONN_TXN_RTS_SWEEP_HS_KEYS 1428
/*! transaction: rollback to stable tree walk skipping pages */
-#define WT_STAT_CONN_TXN_RTS_TREE_WALK_SKIP_PAGES 1426
+#define WT_STAT_CONN_TXN_RTS_TREE_WALK_SKIP_PAGES 1429
/*! transaction: rollback to stable updates aborted */
-#define WT_STAT_CONN_TXN_RTS_UPD_ABORTED 1427
+#define WT_STAT_CONN_TXN_RTS_UPD_ABORTED 1430
/*! transaction: rollback to stable updates removed from history store */
-#define WT_STAT_CONN_TXN_RTS_HS_REMOVED 1428
+#define WT_STAT_CONN_TXN_RTS_HS_REMOVED 1431
/*! transaction: set timestamp calls */
-#define WT_STAT_CONN_TXN_SET_TS 1429
+#define WT_STAT_CONN_TXN_SET_TS 1432
/*! transaction: set timestamp durable calls */
-#define WT_STAT_CONN_TXN_SET_TS_DURABLE 1430
+#define WT_STAT_CONN_TXN_SET_TS_DURABLE 1433
/*! transaction: set timestamp durable updates */
-#define WT_STAT_CONN_TXN_SET_TS_DURABLE_UPD 1431
+#define WT_STAT_CONN_TXN_SET_TS_DURABLE_UPD 1434
/*! transaction: set timestamp oldest calls */
-#define WT_STAT_CONN_TXN_SET_TS_OLDEST 1432
+#define WT_STAT_CONN_TXN_SET_TS_OLDEST 1435
/*! transaction: set timestamp oldest updates */
-#define WT_STAT_CONN_TXN_SET_TS_OLDEST_UPD 1433
+#define WT_STAT_CONN_TXN_SET_TS_OLDEST_UPD 1436
/*! transaction: set timestamp stable calls */
-#define WT_STAT_CONN_TXN_SET_TS_STABLE 1434
+#define WT_STAT_CONN_TXN_SET_TS_STABLE 1437
/*! transaction: set timestamp stable updates */
-#define WT_STAT_CONN_TXN_SET_TS_STABLE_UPD 1435
+#define WT_STAT_CONN_TXN_SET_TS_STABLE_UPD 1438
/*! transaction: transaction begins */
-#define WT_STAT_CONN_TXN_BEGIN 1436
+#define WT_STAT_CONN_TXN_BEGIN 1439
/*! transaction: transaction checkpoint currently running */
-#define WT_STAT_CONN_TXN_CHECKPOINT_RUNNING 1437
+#define WT_STAT_CONN_TXN_CHECKPOINT_RUNNING 1440
/*! transaction: transaction checkpoint generation */
-#define WT_STAT_CONN_TXN_CHECKPOINT_GENERATION 1438
+#define WT_STAT_CONN_TXN_CHECKPOINT_GENERATION 1441
/*!
* transaction: transaction checkpoint history store file duration
* (usecs)
*/
-#define WT_STAT_CONN_TXN_HS_CKPT_DURATION 1439
+#define WT_STAT_CONN_TXN_HS_CKPT_DURATION 1442
/*! transaction: transaction checkpoint max time (msecs) */
-#define WT_STAT_CONN_TXN_CHECKPOINT_TIME_MAX 1440
+#define WT_STAT_CONN_TXN_CHECKPOINT_TIME_MAX 1443
/*! transaction: transaction checkpoint min time (msecs) */
-#define WT_STAT_CONN_TXN_CHECKPOINT_TIME_MIN 1441
+#define WT_STAT_CONN_TXN_CHECKPOINT_TIME_MIN 1444
/*! transaction: transaction checkpoint most recent time (msecs) */
-#define WT_STAT_CONN_TXN_CHECKPOINT_TIME_RECENT 1442
+#define WT_STAT_CONN_TXN_CHECKPOINT_TIME_RECENT 1445
/*! transaction: transaction checkpoint prepare currently running */
-#define WT_STAT_CONN_TXN_CHECKPOINT_PREP_RUNNING 1443
+#define WT_STAT_CONN_TXN_CHECKPOINT_PREP_RUNNING 1446
/*! transaction: transaction checkpoint prepare max time (msecs) */
-#define WT_STAT_CONN_TXN_CHECKPOINT_PREP_MAX 1444
+#define WT_STAT_CONN_TXN_CHECKPOINT_PREP_MAX 1447
/*! transaction: transaction checkpoint prepare min time (msecs) */
-#define WT_STAT_CONN_TXN_CHECKPOINT_PREP_MIN 1445
+#define WT_STAT_CONN_TXN_CHECKPOINT_PREP_MIN 1448
/*! transaction: transaction checkpoint prepare most recent time (msecs) */
-#define WT_STAT_CONN_TXN_CHECKPOINT_PREP_RECENT 1446
+#define WT_STAT_CONN_TXN_CHECKPOINT_PREP_RECENT 1449
/*! transaction: transaction checkpoint prepare total time (msecs) */
-#define WT_STAT_CONN_TXN_CHECKPOINT_PREP_TOTAL 1447
+#define WT_STAT_CONN_TXN_CHECKPOINT_PREP_TOTAL 1450
/*! transaction: transaction checkpoint scrub dirty target */
-#define WT_STAT_CONN_TXN_CHECKPOINT_SCRUB_TARGET 1448
+#define WT_STAT_CONN_TXN_CHECKPOINT_SCRUB_TARGET 1451
/*! transaction: transaction checkpoint scrub time (msecs) */
-#define WT_STAT_CONN_TXN_CHECKPOINT_SCRUB_TIME 1449
+#define WT_STAT_CONN_TXN_CHECKPOINT_SCRUB_TIME 1452
/*! transaction: transaction checkpoint total time (msecs) */
-#define WT_STAT_CONN_TXN_CHECKPOINT_TIME_TOTAL 1450
+#define WT_STAT_CONN_TXN_CHECKPOINT_TIME_TOTAL 1453
/*! transaction: transaction checkpoints */
-#define WT_STAT_CONN_TXN_CHECKPOINT 1451
+#define WT_STAT_CONN_TXN_CHECKPOINT 1454
/*!
* transaction: transaction checkpoints skipped because database was
* clean
*/
-#define WT_STAT_CONN_TXN_CHECKPOINT_SKIPPED 1452
+#define WT_STAT_CONN_TXN_CHECKPOINT_SKIPPED 1455
/*! transaction: transaction failures due to history store */
-#define WT_STAT_CONN_TXN_FAIL_CACHE 1453
+#define WT_STAT_CONN_TXN_FAIL_CACHE 1456
/*!
* transaction: transaction fsync calls for checkpoint after allocating
* the transaction ID
*/
-#define WT_STAT_CONN_TXN_CHECKPOINT_FSYNC_POST 1454
+#define WT_STAT_CONN_TXN_CHECKPOINT_FSYNC_POST 1457
/*!
* transaction: transaction fsync duration for checkpoint after
* allocating the transaction ID (usecs)
*/
-#define WT_STAT_CONN_TXN_CHECKPOINT_FSYNC_POST_DURATION 1455
+#define WT_STAT_CONN_TXN_CHECKPOINT_FSYNC_POST_DURATION 1458
/*! transaction: transaction range of IDs currently pinned */
-#define WT_STAT_CONN_TXN_PINNED_RANGE 1456
+#define WT_STAT_CONN_TXN_PINNED_RANGE 1459
/*! transaction: transaction range of IDs currently pinned by a checkpoint */
-#define WT_STAT_CONN_TXN_PINNED_CHECKPOINT_RANGE 1457
+#define WT_STAT_CONN_TXN_PINNED_CHECKPOINT_RANGE 1460
/*! transaction: transaction range of timestamps currently pinned */
-#define WT_STAT_CONN_TXN_PINNED_TIMESTAMP 1458
+#define WT_STAT_CONN_TXN_PINNED_TIMESTAMP 1461
/*! transaction: transaction range of timestamps pinned by a checkpoint */
-#define WT_STAT_CONN_TXN_PINNED_TIMESTAMP_CHECKPOINT 1459
+#define WT_STAT_CONN_TXN_PINNED_TIMESTAMP_CHECKPOINT 1462
/*!
* transaction: transaction range of timestamps pinned by the oldest
* active read timestamp
*/
-#define WT_STAT_CONN_TXN_PINNED_TIMESTAMP_READER 1460
+#define WT_STAT_CONN_TXN_PINNED_TIMESTAMP_READER 1463
/*!
* transaction: transaction range of timestamps pinned by the oldest
* timestamp
*/
-#define WT_STAT_CONN_TXN_PINNED_TIMESTAMP_OLDEST 1461
+#define WT_STAT_CONN_TXN_PINNED_TIMESTAMP_OLDEST 1464
/*! transaction: transaction read timestamp of the oldest active reader */
-#define WT_STAT_CONN_TXN_TIMESTAMP_OLDEST_ACTIVE_READ 1462
+#define WT_STAT_CONN_TXN_TIMESTAMP_OLDEST_ACTIVE_READ 1465
/*! transaction: transaction sync calls */
-#define WT_STAT_CONN_TXN_SYNC 1463
+#define WT_STAT_CONN_TXN_SYNC 1466
/*! transaction: transactions committed */
-#define WT_STAT_CONN_TXN_COMMIT 1464
+#define WT_STAT_CONN_TXN_COMMIT 1467
/*! transaction: transactions rolled back */
-#define WT_STAT_CONN_TXN_ROLLBACK 1465
+#define WT_STAT_CONN_TXN_ROLLBACK 1468
/*! transaction: update conflicts */
-#define WT_STAT_CONN_TXN_UPDATE_CONFLICT 1466
+#define WT_STAT_CONN_TXN_UPDATE_CONFLICT 1469
/*!
* @}
diff --git a/src/third_party/wiredtiger/src/support/stat.c b/src/third_party/wiredtiger/src/support/stat.c
index c2411d79c75..6ba51a94cab 100644
--- a/src/third_party/wiredtiger/src/support/stat.c
+++ b/src/third_party/wiredtiger/src/support/stat.c
@@ -843,6 +843,9 @@ static const char *const __stats_connection_desc[] = {
"cache: history store score", "cache: history store table insert calls",
"cache: history store table insert calls that returned restart",
"cache: history store table max on-disk size", "cache: history store table on-disk size",
+ "cache: history store table out-of-order resolved updates that lose their durable timestamp",
+ "cache: history store table out-of-order updates that were fixed up by moving existing records",
+ "cache: history store table out-of-order updates that were fixed up during insertion",
"cache: history store table reads", "cache: history store table reads missed",
"cache: history store table reads requiring squashed modifies",
"cache: history store table remove calls due to key truncation",
@@ -1252,6 +1255,9 @@ __wt_stat_connection_clear_single(WT_CONNECTION_STATS *stats)
stats->cache_hs_insert_restart = 0;
/* not clearing cache_hs_ondisk_max */
/* not clearing cache_hs_ondisk */
+ stats->cache_hs_order_lose_durable_timestamp = 0;
+ stats->cache_hs_order_fixup_move = 0;
+ stats->cache_hs_order_fixup_insert = 0;
stats->cache_hs_read = 0;
stats->cache_hs_read_miss = 0;
stats->cache_hs_read_squash = 0;
@@ -1744,6 +1750,10 @@ __wt_stat_connection_aggregate(WT_CONNECTION_STATS **from, WT_CONNECTION_STATS *
to->cache_hs_insert_restart += WT_STAT_READ(from, cache_hs_insert_restart);
to->cache_hs_ondisk_max += WT_STAT_READ(from, cache_hs_ondisk_max);
to->cache_hs_ondisk += WT_STAT_READ(from, cache_hs_ondisk);
+ to->cache_hs_order_lose_durable_timestamp +=
+ WT_STAT_READ(from, cache_hs_order_lose_durable_timestamp);
+ to->cache_hs_order_fixup_move += WT_STAT_READ(from, cache_hs_order_fixup_move);
+ to->cache_hs_order_fixup_insert += WT_STAT_READ(from, cache_hs_order_fixup_insert);
to->cache_hs_read += WT_STAT_READ(from, cache_hs_read);
to->cache_hs_read_miss += WT_STAT_READ(from, cache_hs_read_miss);
to->cache_hs_read_squash += WT_STAT_READ(from, cache_hs_read_squash);
diff --git a/src/third_party/wiredtiger/src/history/hs.c b/src/third_party/wiredtiger/src/history/hs.c
index 3b7c9a69de7..f133eacbeec 100644
--- a/src/third_party/wiredtiger/src/history/hs.c
+++ b/src/third_party/wiredtiger/src/history/hs.c
@@ -706,6 +706,7 @@ __wt_hs_insert_updates(WT_SESSION_IMPL *session, WT_PAGE *page, WT_MULTI *multi)
uint32_t i;
uint8_t *p;
int nentries;
+ char ts_string[3][WT_TS_INT_STRING_SIZE];
bool clear_hs, enable_reverse_modify, squashed, ts_updates_in_hs;
btree = S2BT(session);
@@ -799,15 +800,25 @@ __wt_hs_insert_updates(WT_SESSION_IMPL *session, WT_PAGE *page, WT_MULTI *multi)
non_aborted_upd = upd;
- /*
- * If we've seen a smaller timestamp before, use that instead.
- *
- * FIXME-WT-6442: Resolved prepared updates will lose their durable timestamp here. We
- * should add a statistic to keep track of how often this happens.
- */
- if (min_insert_ts < upd->start_ts)
+ /* If we've seen a smaller timestamp before, use that instead. */
+ if (min_insert_ts < upd->start_ts) {
+ /*
+ * Resolved prepared updates will lose their durable timestamp here. This is a
+ * wrinkle in our handling of out-of-order updates.
+ */
+ if (upd->start_ts != upd->durable_ts) {
+ WT_ASSERT(session, min_insert_ts < upd->durable_ts);
+ WT_STAT_CONN_INCR(session, cache_hs_order_lose_durable_timestamp);
+ }
+ __wt_verbose(session, WT_VERB_TIMESTAMP,
+ "fixing out-of-order updates during insertion; start_ts=%s, durable_start_ts=%s, "
+ "min_insert_ts=%s",
+ __wt_timestamp_to_string(upd->start_ts, ts_string[0]),
+ __wt_timestamp_to_string(upd->durable_ts, ts_string[1]),
+ __wt_timestamp_to_string(min_insert_ts, ts_string[2]));
upd->start_ts = upd->durable_ts = min_insert_ts;
- else
+ WT_STAT_CONN_INCR(session, cache_hs_order_fixup_insert);
+ } else
min_insert_ts = upd->start_ts;
WT_ERR(__wt_modify_vector_push(&modifies, upd));
@@ -957,7 +968,6 @@ __wt_hs_insert_updates(WT_SESSION_IMPL *session, WT_PAGE *page, WT_MULTI *multi)
*/
if (stop_time_point.ts < upd->start_ts ||
(stop_time_point.ts == upd->start_ts && stop_time_point.txnid <= upd->txnid)) {
- char ts_string[2][WT_TS_INT_STRING_SIZE];
__wt_verbose(session, WT_VERB_TIMESTAMP,
"Warning: fixing out-of-order timestamps %s earlier than previous update %s",
__wt_timestamp_to_string(stop_time_point.ts, ts_string[0]),
@@ -1467,6 +1477,7 @@ __hs_fixup_out_of_order_from_pos(WT_SESSION_IMPL *session, WT_CURSOR *hs_cursor,
uint64_t hs_counter;
uint32_t hs_btree_id;
int cmp;
+ char ts_string[5][WT_TS_INT_STRING_SIZE];
const char *open_cursor_cfg[] = {WT_CONFIG_BASE(session, WT_SESSION_open_cursor), NULL};
insert_cursor = NULL;
@@ -1560,6 +1571,23 @@ __hs_fixup_out_of_order_from_pos(WT_SESSION_IMPL *session, WT_CURSOR *hs_cursor,
F_SET(insert_cbt, WT_CBT_NO_TXN);
}
+ /*
+ * If these history store records are resolved prepared updates, their durable timestamps
+ * will be clobbered by our fix-up process. Keep track of how often this is happening.
+ */
+ if (hs_cbt->upd_value->tw.start_ts != hs_cbt->upd_value->tw.durable_start_ts ||
+ hs_cbt->upd_value->tw.stop_ts != hs_cbt->upd_value->tw.durable_stop_ts)
+ WT_STAT_CONN_INCR(session, cache_hs_order_lose_durable_timestamp);
+
+ __wt_verbose(session, WT_VERB_TIMESTAMP,
+ "fixing existing out-of-order updates by moving them; start_ts=%s, durable_start_ts=%s, "
+ "stop_ts=%s, durable_stop_ts=%s, new_ts=%s",
+ __wt_timestamp_to_string(hs_cbt->upd_value->tw.start_ts, ts_string[0]),
+ __wt_timestamp_to_string(hs_cbt->upd_value->tw.durable_start_ts, ts_string[1]),
+ __wt_timestamp_to_string(hs_cbt->upd_value->tw.stop_ts, ts_string[2]),
+ __wt_timestamp_to_string(hs_cbt->upd_value->tw.durable_stop_ts, ts_string[3]),
+ __wt_timestamp_to_string(ts, ts_string[4]));
+
start_time_point.ts = start_time_point.durable_ts = ts;
start_time_point.txnid = hs_cbt->upd_value->tw.start_txn;
@@ -1588,6 +1616,7 @@ __hs_fixup_out_of_order_from_pos(WT_SESSION_IMPL *session, WT_CURSOR *hs_cursor,
;
WT_ERR(ret);
tombstone = NULL;
+ WT_STAT_CONN_INCR(session, cache_hs_order_fixup_move);
}
if (ret == WT_NOTFOUND)
ret = 0;